Clojure only.

codax.swaps


dec-countclj

(dec-count x)

Used for decrementing a counter that may not be initialized. If x is not a positive integer, dec-count evaluates to 0

Used for decrementing a counter that may not be initialized.
If `x` is not a positive integer, `dec-count` evaluates to 0
sourceraw docstring

inc-countclj

(inc-count x)

Used for incrementing a counter that may not be initialized. If x is not a positive integer, inc-count evaluates to 1

Used for incrementing a counter that may not be initialized.
If `x` is not a positive integer, `inc-count` evaluates to 1
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries