(dec-count x)Used for decrementing a counter that may not be initialized.
If x is not a positive integer, dec-count evaluates to 0
Used for decrementing a counter that may not be initialized. If `x` is not a positive integer, `dec-count` evaluates to 0
(inc-count x)Used for incrementing a counter that may not be initialized.
If x is not a positive integer, inc-count evaluates to 1
Used for incrementing a counter that may not be initialized. If `x` is not a positive integer, `inc-count` evaluates to 1
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |